###################################################
### chunk number 1: 
###################################################
options(prompt = ' ')
options(continue = ' ')
options(width = 60)
RweaveLatexOptions(list(width = 4, height = 4)) # make 4 inch by 4 inch the default figure size


###################################################
### chunk number 2: 
###################################################
set.seed(1) 
nSubj <- 40
doses <- c(0, 10, 30, 100)
times <- seq(0, 9, 3)

dat <- expand.grid(Subject = 1:nSubj,
                   Month = times)
dat <- as.data.frame(dat)

dat$Dose <- doses[as.numeric(dat$Subject) %% length(doses) + 1]
dat$Exposure <- dat$Dose * exp(rnorm(nrow(dat), 0, 0.3))
noise <- rep(rnorm(nSubj, 0, 0.2), length(doses)) + rnorm(nrow(dat), 0, 0.2)
emax <- c(0, 50, 100, 100)[match(dat$Month, times)]
dat$Response <- with(dat, 10 + emax * Exposure / (Exposure + 25)) * exp(noise)
dat$Response <- pmin(dat$Response, 100)  


###################################################
### chunk number 3: 
###################################################
sample.rows <- sample(1:nrow(dat), 10)
dat[sample.rows, ]


###################################################
### chunk number 4: 
###################################################
pdf(file = 'test.pdf')


###################################################
### chunk number 5: 
###################################################
plot(dat$Exposure, dat$Response)


###################################################
### chunk number 6: 
###################################################
abline(h = 50)


###################################################
### chunk number 7: 
###################################################
dev.off()


###################################################
### chunk number 8: 
###################################################
pdf()
plot(1:10, 11:20)
dev.off()


###################################################
### chunk number 9: 
###################################################
plot(log(dat$Exposure[dat$Dose != 0]), dat$Response[dat$Dose != 0])


###################################################
### chunk number 10: 
###################################################
plot(dat$Response[dat$Dose != 0] ~ log(dat$Exposure[dat$Dose != 0]))


###################################################
### chunk number 11: 
###################################################
plot(Response ~ log(Exposure),
     data = dat,
     subset = Dose != 0)


###################################################
### chunk number 12: 
###################################################
plot(Response ~ Exposure,
     data = dat,
     main = 'Exposure-response Relationship',
     xlab = 'Concentration (ng / mL)',
     ylab = "Dr. Eynobest's Assessment Scale"
     )


###################################################
### chunk number 13: 
###################################################
plot(Response ~ Exposure, 
     data = dat,
     main = 'Exposure-response Relationship',
     xlab = 'Concentration (ng / mL)',
     ylab = "Dr. Eynobest's Assessment Scale"
     )

points(mean(dat$Exposure), mean(dat$Response), 
       pch = 19, # this specifies solid circles 
       cex = 2) # this specifies 2x the default size

v.reflines <- quantile(dat$Exposure, probs = c(0.25, 0.5, 0.75))
h.reflines <- quantile(dat$Response, probs = c(0.25, 0.5, 0.75))
abline(v = v.reflines, lty = 2) # lty = 2 means dashed lines
abline(h = v.reflines, lty = 2)


###################################################
### chunk number 14: 
###################################################
library(lattice)


###################################################
### chunk number 15: 
###################################################
xyplot(1:10 ~ 11:20)


###################################################
### chunk number 16: 
###################################################
print(
      xyplot(Response ~ Exposure,
             data = dat,
             main = 'Exposure-response Relationship',
             xlab = 'Concentration (ng / mL)',
             ylab = "Dr. Eynobest's Assessment Scale"
             )
      )


###################################################
### chunk number 17: 
###################################################
print(
      xyplot(Response ~ Exposure | Month,
             data = dat,
             main = 'Exposure-response Relationship',
             xlab = 'Concentration (ng / mL)',
             ylab = "Dr. Eynobest's Assessment Scale"
             )
      )


###################################################
### chunk number 18: 
###################################################
print(
      xyplot(Response ~ Exposure | Month,
             data = dat,
             layout = c(4, 1), # this means 4 columns, 1 row
             main = 'Exposure-response Relationship by Month',
             xlab = 'Concentration (ng / mL)',
             ylab = "Dr. Eynobest's Assessment Scale"
             )
      )


###################################################
### chunk number 19: 
###################################################
str(dat$Month)


###################################################
### chunk number 20:  eval=FALSE
###################################################
## dat$Month2 <- paste("Month", dat$Month)
## str(dat$Month2)
## print(
##       xyplot(Response ~ Exposure | Month2,
##              data = dat,
##              layout = c(4, 1), 
##              main = 'Exposure-response Relationship by Month',
##              xlab = 'Concentration (ng / mL)',
##              ylab = "Dr. Eynobest's Assessment Scale"
##              )
##       )


###################################################
### chunk number 21: 
###################################################
print(
      xyplot(Response ~ Exposure | paste("Month", Month),
             data = dat,
             layout = c(4, 1), 
             main = 'Exposure-response Relationship by Month',
             xlab = 'Concentration (ng / mL)',
             ylab = "Dr. Eynobest's Assessment Scale"
             )
      )


###################################################
### chunk number 22: 
###################################################
print(
      xyplot(Response ~ Month | paste(Dose, 'mg'), 
             data = dat,
             layout = c(4, 1),
             )
      )


###################################################
### chunk number 23: 
###################################################
dat$Dose2 <- paste(dat$Dose, 'mg')


###################################################
### chunk number 24: 
###################################################
dat$Dose2[dat$Dose2 == '0 mg'] <- 'Placebo'


###################################################
### chunk number 25: 
###################################################
dat$Dose2 <- factor(dat$Dose2)


###################################################
### chunk number 26: 
###################################################
levels(dat$Dose2)


###################################################
### chunk number 27: 
###################################################
levels(dat$Dose2)[c(4, 1, 3, 2)]


###################################################
### chunk number 28: 
###################################################
newlevs <- levels(dat$Dose2)[c(4, 1, 3, 2)]
dat$Dose2 <- factor(dat$Dose2, levels = newlevs)
levels(dat$Dose2)


###################################################
### chunk number 29: 
###################################################
print(
      xyplot(Response ~ Month | Dose2, 
             data = dat,
             layout = c(4, 1), 
             )
      )


###################################################
### chunk number 30: 
###################################################
print(
      xyplot(Response ~ Month | paste(Dose, 'mg'), 
             data = dat,
             index.cond = list(c(1, 2, 4, 3)) 
      )
      )


###################################################
### chunk number 31: 
###################################################
print(
      xyplot(Response ~ Month | Dose2,
             groups = Subject,
             data = dat)
      )


###################################################
### chunk number 32: 
###################################################
print(
      xyplot(Response ~ Month | Dose2,
             groups = Subject,
             data = dat,
             type = 'l' 
             ## or type = 'b' if you want (b)oth points
             ## and lines
             )
      )


###################################################
### chunk number 33: 
###################################################
print(
      xyplot(Response ~ Month | Dose2,
             groups = Subject,
             data = dat,
             type = 'l',
             col = 'black'
             )
      )


###################################################
### chunk number 34: 
###################################################
print(
      xyplot(Response ~ Exposure | Month,
             groups = Dose,
             data = dat)
      )


###################################################
### chunk number 35: 
###################################################
print(
      xyplot(Response ~ Exposure | Month,
             groups = Dose,
             auto.key = TRUE,
             data = dat)
      )


###################################################
### chunk number 36: 
###################################################
print(
      xyplot(Response ~ Exposure | Month,
             groups = Dose,
             auto.key = list(title = 'Dose (mg)', space = 'bottom',
               columns = 4, border = TRUE),
             data = dat)
      )


###################################################
### chunk number 37: 
###################################################
print(
      xyplot(Response ~ Exposure | Month,
             groups = Dose,
             auto.key = list(title = 'Dose (mg)', space = 'bottom',
               columns = 4, border = TRUE),
             scales = list(relation = "free"), 
             data = dat
             )
      )


###################################################
### chunk number 38: 
###################################################
print(
      xyplot(Response ~ Exposure | Month,
             groups = Dose,
             auto.key = list(title = 'Dose (mg)', space = 'bottom',
               columns = 4, border = TRUE),
             scales = list(
               x = list(relation = "same"), 
               y = list(relation = "free")
               ), 
             data = dat
             )
      )


###################################################
### chunk number 39: 
###################################################
print(
      xyplot(Response ~ Exposure | Month,
             groups = Dose,
             auto.key = list(title = 'Dose (mg)', space = 'bottom',
               columns = 4, border = TRUE),
             scales = list(
               x = list(relation = "same"), 
               y = list(relation = "sliced")
               ), 
             data = dat
             )
      )


