###################################################
### chunk number 2: 
###################################################
set.seed(1) 
nSubj <- 40
doses <- c(0, 10, 30, 100)
times <- seq(0, 9, 3)

dat <- expand.grid(Subject = 1:nSubj,
                   Month = times)
dat <- as.data.frame(unclass(dat))

dat$Dose <- doses[as.numeric(dat$Subject) %% length(doses) + 1]
dat$Exposure <- dat$Dose * exp(rnorm(nrow(dat), 0, 0.3))
noise <- rep(rnorm(nSubj, 0, 0.2), length(doses)) + rnorm(nrow(dat), 0, 0.2)
emax <- c(0, 50, 100, 100)[match(dat$Month, times)]
dat$Response <- with(dat, 10 + emax * Exposure / (Exposure + 25)) * exp(noise)
dat$Response <- pmin(dat$Response, 100)  

dat$Dose2 <- factor(paste(dat$Dose, "mg"))
dat$Dose2 <- factor(dat$Dose2, levels = levels(dat$Dose2)[c(1, 2, 4, 3)])

dat$Sex <- rep(sample(c("M", "F"), nSubj, replace = TRUE), length(times))


###################################################
### chunk number 3: 
###################################################
library(lattice)


###################################################
### chunk number 4: 
###################################################
print(
xyplot(Response ~ Exposure | paste("Month", Month),
       data = dat,
       layout = c(4, 1), 
       panel = panel.xyplot, 
       )
      )


###################################################
### chunk number 5: 
###################################################
print(
xyplot(Response ~ Exposure | paste("Month", Month),
       data = dat,
       layout = c(4, 1), 
       panel = panel.loess, 
       )
      )


###################################################
### chunk number 6: 
###################################################
my.panel <- function(x, y, 
                     my.point.color = "blue", 
                     my.loess.color = "red") { 
  panel.xyplot(x, y, col = my.point.color)
  panel.loess(x, y, col = my.loess.color)
  return(NULL)
}


###################################################
### chunk number 7: 
###################################################
print(
xyplot(Response ~ Exposure | paste("Month", Month),
       data = dat,
       layout = c(4, 1), 
       panel = my.panel, 
       )
      )

xyplot(Response ~ Exposure | paste("Month", Month),
       data = dat,
       layout = c(4, 1), 
       panel = function(x, y, 
                     my.point.color = "blue", 
                     my.loess.color = "red") { 
                  panel.xyplot(x, y, col = my.point.color)
                  ## panel.loess(x, y, col = my.loess.color)
                  return(NULL)
                 }
       )

plot(1, 1)
## other stuff
abline(h = 1)

###################################################
### chunk number 8: 
###################################################


print(
histogram( ~ Exposure | Dose2,
          data = dat,
          layout = c(1, 4),
          panel = function(x) {
            panel.histogram(x, breaks = seq(0, 200, 10), type = 'percent')
            panel.rug(x)
          },
           scales = list(y = list(relation = 'free'))
         )
      )


###################################################
### chunk number 9: 
###################################################
print(
xyplot(Response ~ Exposure | paste("Month", Month),
       data = dat,
       layout = c(4, 1), 
       panel = my.panel, 
       my.point.color = "red", 
       my.loess.color = "blue"
       )
      )


###################################################
### chunk number 10: 
###################################################
my.panel <- function(x, y, 
                     my.point.color = "blue", 
                     my.loess.color = "red"
                     ## ... 
                     ## "..." is like saying "and
                     ## whatever else I didn't think of" 
                     ) {
  panel.xyplot(x, y, col = my.point.color)
  panel.loess(x, y, col = my.loess.color) # , ...)
  return(NULL)
}


###################################################
### chunk number 11: 
###################################################
print(
xyplot(Response ~ Exposure | paste("Month", Month),
       data = dat,
       layout = c(4, 1), 
       panel = my.panel, 
       my.point.color = "red", 
       my.loess.color = "blue",
       lty = 2, # gets passed to my.panel as "...",
       lwd = 2
       )
      )


###################################################
### chunk number 12: 
###################################################
print(
histogram( ~ Exposure | Dose2 * paste("Month", Month),
          data = dat,
          panel = function(x, ...) {
            panel.histogram(x, ...)
            xmean <- mean(x)
            xquantile <- quantile(x, probs = c(0.05, 0.95))
            panel.abline(v = xmean)
            panel.abline(v = xquantile, lty = 2)
          }
         )
      )


###################################################
### chunk number 13: 
###################################################
dat2 <- dat
nr <- nrow(dat2)
make.missing <- sample(seq(nr), floor(nr/10), prob = dat2$Response)
dat2$Response[ make.missing ] <- NA  


xyplot(Response ~ Exposure | Dose2, 
       data = dat2,
       layout = c(4, 1), 
       panel = function(x, y, ...) { 
          panel.xyplot(x, y, ...)
          whichmiss <- is.na(y)
          x.where.yna <- x[whichmiss]
          ## x.where.yna <- x[is.na(y)]
          panel.rug(x.where.yna)
         }, 
       scales = list(x = list(relation = 'free'))
       )

###################################################
### chunk number 14: 
###################################################
print(
xyplot(Response ~ Exposure | Dose2,
       data = dat2,
       panel = function(x, y, ...) {
         panel.xyplot(x, y, ...)
         xna <- x[ is.na(y) ]
         panel.rug(xna)
       }, 
       layout = c(4, 1), 
       scales = list(x = list(relation = "free"))
       )
      )


###################################################
### chunk number 15: 
###################################################
xyplot(Response ~ Exposure | Month,
       groups = Sex, 
       data = dat
      )


###################################################
### chunk number 16: 
###################################################
xyplot(Response ~ Exposure | Month,
       groups = Sex, 
       data = dat,
       panel = panel.superpose,
       panel.groups = panel.xyplot
       )


###################################################
### chunk number 17: 
###################################################
print(
xyplot(Response ~ Exposure | Month,
       groups = Sex, 
       data = dat,
       panel = function(x, y, ...) { 
         panel.superpose(x, y, ...)
         panel.loess(x, y)
         }, 
       panel.groups = panel.xyplot,
       layout = c(4, 1), 
       auto.key = TRUE
       )
      )


###################################################
### chunk number 18: 
###################################################
print(
xyplot(Response ~ Exposure | Month,
       groups = Sex, 
       data = dat,
       panel = panel.superpose, 
       panel.groups = function(x, y, ...) {
         panel.xyplot(x, y, ...)
         panel.loess(x, y)
       }, 
       layout = c(4, 1), 
       auto.key = TRUE
       )
      )


###################################################
### chunk number 19: 
###################################################
print(
xyplot(Response ~ Exposure | Month,
       groups = Sex, 
       data = dat,
       panel = panel.superpose, 
       panel.groups = function(x, y, ...) {
         panel.xyplot(x, y, ...)
         panel.loess(x, y, ...)
       }, 
       layout = c(4, 1), 
       auto.key = TRUE
       )
      )


###################################################
### chunk number 20: 
###################################################
show.settings()


###################################################
### chunk number 21: 
###################################################
trellis.par.get('superpose.symbol')


###################################################
### chunk number 22: 
###################################################
trellis.par.get('superpose.line')


###################################################
### chunk number 23: 
###################################################
trellis.par.set(superpose.symbol = list(pch = 1:7))
trellis.par.set(superpose.line = list(lty = 1:7))


###################################################
### chunk number 24: 
###################################################
show.settings()


###################################################
### chunk number 25: 
###################################################
print(
xyplot(Response ~ Exposure | Month,
       groups = Sex, 
       data = dat,
       panel = panel.superpose, 
       panel.groups = function(x, y, ...) {
         panel.xyplot(x, y, ...)
         panel.loess(x, y, ...)
       }, 
       layout = c(4, 1), 
       auto.key = TRUE
       )
      )


###################################################
### chunk number 26: 
###################################################
print(
xyplot(Response ~ Exposure | Month,
       groups = Sex, 
       data = dat,
       col = c("green", "blue"), 
       pch = 3:4, 
       panel = panel.superpose, 
       panel.groups = function(x, y, ...) {
         panel.xyplot(x, y, ...)
         panel.loess(x, y, ...)
       }, 
       layout = c(4, 1), 
       auto.key = TRUE
       )
      )



