
set.seed(1) 
nSubj <- 40
doses <- c(0, 10, 30, 100)
times <- seq(0, 9, 3)

dat <- expand.grid(Subject = 1:nSubj,
                   Month = times)
dat <- as.data.frame(unclass(dat))

dat$Dose <- doses[as.numeric(dat$Subject) %% length(doses) + 1]
dat$Exposure <- dat$Dose * exp(rnorm(nrow(dat), 0, 0.3))
noise <- rep(rnorm(nSubj, 0, 0.2), length(doses)) + rnorm(nrow(dat), 0, 0.2)
emax <- c(0, 50, 100, 100)[match(dat$Month, times)]
dat$Response <- with(dat, 10 + emax * Exposure / (Exposure + 25)) * exp(noise)
dat$Response <- pmin(dat$Response, 100)  

dat$Dose2 <- factor(paste(dat$Dose, "mg"))
dat$Dose2 <- factor(dat$Dose2, levels = levels(dat$Dose2)[c(1, 2, 4, 3)])

dat$Sex <- rep(sample(c("M", "F"), nSubj, replace = TRUE), length(times))


library(lattice)


## Answers to Section 5.8, "Homework"

## 1. 
xyplot(Response ~ Month | Dose2, 
       data = dat,
       groups = Subject, 
       panel = function(x, y, ...) { 
         panel.superpose(x, y, ...) 
         my <- tapply(y, x, mean)
         ux <- sort(unique(x))
         panel.xyplot(ux, my, col = 'black', type = 'l', lwd = 2)
         },
       panel.groups = function(x, y, ...) { 
         panel.xyplot(x, y, col = 'lightgrey', type = 'l')
         }
       )

## 2. 

default.theme <- trellis.par.get()

trellis.par.set(superpose.symbol = list(pch = c(1, rep(3, 3)), 
                                        col = c('blue', rep('red', 3)),
                                        cex = c(1, 1:3)
                                        )
                )
xyplot(Response ~ Exposure | Month, 
        data = dat,
        groups = Dose, 
        auto.key = TRUE)

trellis.par.set(default.theme)
