###################################################
### chunk number 1: 
###################################################
#line 5 "modelinginr.Rnw"
options(prompt = ' ')
options(continue = ' ')
options(width = 60)
RweaveLatexOptions(list(width = 4, height = 4)) # make 4 inch by 4 inch the default figure size


###################################################
### chunk number 2: 
###################################################
#line 70 "modelinginr.Rnw"
set.seed(1) 
nSubj <- 40
doses <- c(0, 10, 30, 100)
times <- seq(0, 9, 3)

dat <- expand.grid(Subject = 1:nSubj,
                   Month = times)
dat <- as.data.frame(unclass(dat))

dat$Dose <- doses[as.numeric(dat$Subject) %% length(doses) + 1]
dat$Exposure <- dat$Dose * exp(rnorm(nrow(dat), 0, 0.3))
noise <- rep(rnorm(nSubj, 0, 0.2), length(doses)) + rnorm(nrow(dat), 0, 0.2)
emax <- c(0, 50, 100, 100)[match(dat$Month, times)]
dat$Response <- with(dat, 10 + emax * Exposure / (Exposure + 25)) * exp(noise)
dat$Response <- pmin(dat$Response, 100)  

dat$Dose2 <- factor(paste(dat$Dose, "mg"))
dat$Dose2 <- factor(dat$Dose2, levels = levels(dat$Dose2)[c(1, 2, 4, 3)])

dat$Sex <- rep(sample(c("M", "F"), nSubj, replace = TRUE), length(times))

dat$Response[dat$Month == 9 & dat$Subject == 1] <- NA


###################################################
### chunk number 3: 
###################################################
#line 100 "modelinginr.Rnw"
library(lattice)
print(
      xyplot(Response ~ Dose,
             subset = Month == 9 & Dose < 40, 
             data = dat)
      )


###################################################
### chunk number 4: 
###################################################
#line 120 "modelinginr.Rnw"
mod1 <- lm(Response ~ Dose,
           subset =  Month == 9 & Dose < 40, 
           data = dat)


###################################################
### chunk number 5: 
###################################################
#line 141 "modelinginr.Rnw"
class(mod1)


###################################################
### chunk number 6: 
###################################################
#line 148 "modelinginr.Rnw"
mod1


###################################################
### chunk number 7: 
###################################################
#line 160 "modelinginr.Rnw"
lm(Response ~ -1 + Dose,
   subset =  Month == 9 & Dose < 40, 
   data = dat)


###################################################
### chunk number 8: 
###################################################
#line 169 "modelinginr.Rnw"
lm(Response ~ 1, 
   subset =  Month == 9 & Dose < 40, 
   data = dat)


###################################################
### chunk number 9: 
###################################################
#line 188 "modelinginr.Rnw"
summary(mod1)


###################################################
### chunk number 10: 
###################################################
#line 194 "modelinginr.Rnw"
anova(mod1)


###################################################
### chunk number 11: 
###################################################
#line 200 "modelinginr.Rnw"
plot(mod1, which = 1) # If using R interactively, try this without "which = 1"


###################################################
### chunk number 12: 
###################################################
#line 204 "modelinginr.Rnw"
plot(mod1, which = 2) 


###################################################
### chunk number 13: 
###################################################
#line 208 "modelinginr.Rnw"
plot(mod1, which = 3) 


###################################################
### chunk number 14: 
###################################################
#line 219 "modelinginr.Rnw"
coef(mod1)


###################################################
### chunk number 15: 
###################################################
#line 223 "modelinginr.Rnw"
confint(mod1)


###################################################
### chunk number 16: 
###################################################
#line 227 "modelinginr.Rnw"
predict(mod1)  


###################################################
### chunk number 17: 
###################################################
#line 235 "modelinginr.Rnw"
resid(mod1)


###################################################
### chunk number 18: 
###################################################
#line 239 "modelinginr.Rnw"
AIC(mod1)


###################################################
### chunk number 19: 
###################################################
#line 252 "modelinginr.Rnw"
mod1.1 <- lm(Response ~ Dose, 
             subset =  Month == 9 & Dose < 40, 
             data = dat, 
             na.action = na.exclude) 


###################################################
### chunk number 20: 
###################################################
#line 259 "modelinginr.Rnw"
predict(mod1.1)


###################################################
### chunk number 21: 
###################################################
#line 267 "modelinginr.Rnw"
predict(mod1.1, 
        newdata = subset(dat,  
          Month == 9 & Dose < 40, 
          select = Dose)
        )


###################################################
### chunk number 22: 
###################################################
#line 281 "modelinginr.Rnw"
print(
      xyplot(Response ~ factor(Dose),
             subset = Month == 9 & Dose < 40, 
             data = dat)
      )


###################################################
### chunk number 23: 
###################################################
#line 298 "modelinginr.Rnw"
mod2 <- lm(Response ~ factor(Dose),
           subset =  Month == 9 & Dose < 40, 
           data = dat)
summary(mod2)


###################################################
### chunk number 24: 
###################################################
#line 314 "modelinginr.Rnw"
print(
      xyplot(Response ~ Dose, 
             subset =  Month == 9 & Dose < 40, 
             data = dat,
             panel = function(x, y, ...) { 
               panel.xyplot(x, y, ...)
               ux <- sort(unique(x))
               m1pred <- predict(mod1, newdata = data.frame(Dose = ux))
               m2pred <- predict(mod2, newdata = data.frame(Dose = ux))
               panel.xyplot(ux, m1pred, type = 'l', lwd = 2)
               panel.xyplot(ux, m2pred, pch = 19, cex = 1.5)
               }
             )
      )


###################################################
### chunk number 25: 
###################################################
#line 337 "modelinginr.Rnw"
levels(factor(dat$Dose))[1]


###################################################
### chunk number 26: 
###################################################
#line 364 "modelinginr.Rnw"
print(
      xyplot(log(Response) ~ Dose, 
             subset =  Month == 9 & Dose < 40, 
             data = dat
             )
      )


###################################################
### chunk number 27: 
###################################################
#line 396 "modelinginr.Rnw"
library(nlme)
mod3 <- nls(log(Response) ~ alpha + Dose^beta, 
            subset =  Month == 9 & Dose < 40, 
            data = dat, 
            start = list(alpha = log(10), beta = 0.5)
            )


###################################################
### chunk number 28: 
###################################################
#line 407 "modelinginr.Rnw"
summary(mod3)


###################################################
### chunk number 29: 
###################################################
#line 411 "modelinginr.Rnw"
confint(mod3)


###################################################
### chunk number 30: 
###################################################
#line 415 "modelinginr.Rnw"
AIC(mod3)


###################################################
### chunk number 31: 
###################################################
#line 419 "modelinginr.Rnw"
print(
      plot(mod3)
      )


###################################################
### chunk number 32: 
###################################################
#line 425 "modelinginr.Rnw"
print(
      xyplot(log(Response) ~ Dose, 
             subset =  Month == 9 & Dose < 40, 
             data = dat,
             panel = function(x, y, ...) { 
               panel.xyplot(x, y, ...)
               xx <- seq(min(x, na.rm = TRUE), max(x, na.rm = TRUE), length = 100)
               m3pred <- predict(mod3, newdata = data.frame(Dose = xx))
               panel.xyplot(xx, m3pred, type = 'l', lwd = 2)
             }
             )
      )


###################################################
### chunk number 33: 
###################################################
#line 452 "modelinginr.Rnw"
print(
      xyplot(Response ~ Month | Subject, data = dat, 
             subset = Month < 9 & Dose == 30, 
             panel = function(x, y, ...) { 
               panel.xyplot(x, y, ...)
               panel.lmline(x, y, ...)
             }
             )      
      )


###################################################
### chunk number 34: 
###################################################
#line 471 "modelinginr.Rnw"
mod4 <- lme(fixed = Response ~ 1 + Month, 
            data = dat, 
            random = ~ 1 | Subject, 
            subset = Month < 9 & Dose == 30
            )
mod4


###################################################
### chunk number 35: 
###################################################
#line 532 "modelinginr.Rnw"
lme(Response ~ 1 + Month, 
            data = dat, 
            random = list(Subject = pdDiag(~ 1 + Month)), 
            subset = Month < 9 & Dose == 30, 
            na.action = na.exclude
            )


###################################################
### chunk number 36: 
###################################################
#line 558 "modelinginr.Rnw"
mod5 <- lme(Response ~ 1 + Month, 
            data = dat, 
            random = list(Subject = pdDiag(~ -1 + Month)), 
            subset = Dose == 30, 
            na.action = na.exclude
            )
mod5


###################################################
### chunk number 37: 
###################################################
#line 570 "modelinginr.Rnw"
mod5 <- lme(Response ~ 1 + Month, 
            data = dat, 
            random = ~ -1 + Month | Subject, 
            subset = Dose == 30, 
            na.action = na.exclude
            )
mod5


###################################################
### chunk number 38: 
###################################################
#line 605 "modelinginr.Rnw"
print(
      xyplot(Response ~ Month | Subject, data = dat, 
             subset = Dose == 30 & Month < 9, 
             panel = function(x, y, subscripts, ...) { 
               panel.xyplot(x, y, ...)
               subjectData <- dat[subscripts, ]
               indPred <- predict(mod5, newdata = subjectData)
               popPred <- predict(mod5, newdata = subjectData, level = 0)
               panel.xyplot(subjectData$Month, indPred, type = "l", lty = 2)
               panel.xyplot(subjectData$Month, popPred, type = "l", lty = 1)
             }
             )      
      )


###################################################
### chunk number 39: 
###################################################
#line 622 "modelinginr.Rnw"
print(
      xyplot(resid(mod5) ~ fitted(mod5))
      )


###################################################
### chunk number 40: 
###################################################
#line 628 "modelinginr.Rnw"
print(
      xyplot(resid(mod5, level = 0) ~ fitted(mod5, level = 0))
      )


###################################################
### chunk number 41: 
###################################################
#line 645 "modelinginr.Rnw"
print(
      xyplot(log(Response) ~ Exposure, 
             data = dat,
             groups = Month,
             panel = function(x, y, ...) {
               panel.superpose(x, y, ...)
             },
             panel.groups = function(x, y, ...) {
               panel.xyplot(x, y, ...)
               panel.loess(x, y, ...)
             } 
             )
      )


###################################################
### chunk number 42: 
###################################################
#line 673 "modelinginr.Rnw"
print(
      xyplot(log(Response) ~ Exposure, 
             data = dat,
             subset = Month %in% c(6, 9),
             groups = Subject,
             type = 'b'
             )
      )


###################################################
### chunk number 43: 
###################################################
#line 698 "modelinginr.Rnw"
tmp1 <- nls(log(Response) ~ SSasymp(Exposure, Asym, R0, lrc),
            data = dat,
            subset = Month %in% c(6, 9)
            )
tmp1


###################################################
### chunk number 44: 
###################################################
#line 708 "modelinginr.Rnw"
print(
      xyplot(log(Response) ~ Exposure, 
             data = dat,
             subset = Month %in% c(6, 9),
             panel = function(x, y, ...) {
               panel.xyplot(x, y, ...)
               xo <- sort(x)
               yo <- y[order(x)]
               panel.xyplot(xo, predict(tmp1, newdata = data.frame(Exposure = xo)), type = 'l')
             }
             )
      )



###################################################
### chunk number 45: 
###################################################
#line 742 "modelinginr.Rnw"
mod6 <- nlme(model = log(Response) ~ SSasymp(Exposure, Asym, R0, lrc),
             data = dat, 
             subset = Month %in% c(6, 9), 
             fixed = list(Asym ~ 1, R0 ~ 1, lrc ~ 1), 
             random = list(Asym ~ 1, R0 ~ 1),
             groups = ~ Subject,
             start = coef(tmp1),
             na.action = na.exclude
             )
mod6


###################################################
### chunk number 46: 
###################################################
#line 759 "modelinginr.Rnw"
print(
      xyplot(log(Response) ~ Month | Subject, data = dat,
             subset = Month %in% c(6, 9), 
             panel = function(x, y, subscripts, ...) { 
               panel.xyplot(x, y, ...)
               subjectData <- dat[subscripts, ]
               indPred <- predict(mod6, newdata = subjectData)
               popPred <- predict(mod6, newdata = subjectData, level = 0)
               panel.xyplot(subjectData$Month, indPred, type = "l", lty = 2)
               panel.xyplot(subjectData$Month, popPred, type = "l", lty = 1)
             }
             ) 
      )


###################################################
### chunk number 47: 
###################################################
#line 785 "modelinginr.Rnw"
p <- coef(tmp1)
mod7 <- nlme(model = log(Response) ~ SSasymp(Exposure, Asym, R0, lrc), 
             data = dat, 
             fixed = list(Asym ~ factor(Month), R0 ~ 1, lrc ~ 1), 
             random = list(Asym ~ 1, R0 ~ 1),
             groups = ~ Subject,
             start = c(p["Asym"], 0, 0, 0, p[c("R0", "lrc")]),
             na.action = na.exclude
             )
mod7


###################################################
### chunk number 48: 
###################################################
#line 800 "modelinginr.Rnw"
print(
      xyplot(log(Response) ~ Month | Subject, data = dat,
             panel = function(x, y, subscripts, ...) { 
               panel.xyplot(x, y, ...)
               subjectData <- dat[subscripts, ]
               indPred <- predict(mod7, newdata = subjectData)
               popPred <- predict(mod7, newdata = subjectData, level = 0)
               panel.xyplot(subjectData$Month, indPred, type = "l", lty = 2)
               panel.xyplot(subjectData$Month, popPred, type = "l", lty = 1)
             }
             ) 
      )


