
###################################################
### chunk number 2: 
###################################################
set.seed(1) 
nSubj <- 40
doses <- c(0, 10, 30, 100)
times <- seq(0, 9, 3)

dat <- expand.grid(Subject = 1:nSubj,
                   Month = times)
dat <- as.data.frame(unclass(dat))

dat$Dose <- doses[as.numeric(dat$Subject) %% length(doses) + 1]
dat$Exposure <- dat$Dose * exp(rnorm(nrow(dat), 0, 0.3))
noise <- rep(rnorm(nSubj, 0, 0.2), length(doses)) + rnorm(nrow(dat), 0, 0.2)
emax <- c(0, 50, 100, 100)[match(dat$Month, times)]
dat$Response <- with(dat, 10 + emax * Exposure / (Exposure + 25)) * exp(noise)
dat$Response <- pmin(dat$Response, 100)  

dat$Dose2 <- factor(paste(dat$Dose, "mg"))
dat$Dose2 <- factor(dat$Dose2, levels = levels(dat$Dose2)[c(1, 2, 4, 3)])

dat$Sex <- rep(sample(c("M", "F"), nSubj, replace = TRUE), length(times))

dat$Response[dat$Month == 9 & dat$Subject == 1] <- NA


###################################################
### chunk number 3: 
###################################################
library(lattice)
print(
      xyplot(Response ~ Dose,
             subset = Month == 9 & Dose < 40, 
             data = dat)
      )


###################################################
### chunk number 4: 
###################################################
mod1 <- lm(Response ~ Dose,
           subset =  Month == 9 & Dose < 40, 
           data = dat)


###################################################
### chunk number 5: 
###################################################
class(mod1)


###################################################
### chunk number 6: 
###################################################
mod1


###################################################
### chunk number 7: 
###################################################
lm(Response ~ -1 + Dose,
   subset =  Month == 9 & Dose < 40, 
   data = dat)


###################################################
### chunk number 8: 
###################################################
lm(Response ~ 1, 
   subset =  Month == 9 & Dose < 40, 
   data = dat)


###################################################
### chunk number 9: 
###################################################
summary(mod1)


###################################################
### chunk number 10: 
###################################################
anova(mod1)


###################################################
### chunk number 11: 
###################################################
plot(mod1, which = 1) # If using R interactively, try this without "which = 1"


###################################################
### chunk number 12: 
###################################################
plot(mod1, which = 2) 


###################################################
### chunk number 13: 
###################################################
plot(mod1, which = 3) 


###################################################
### chunk number 14: 
###################################################
coef(mod1)


###################################################
### chunk number 15: 
###################################################
confint(mod1)


###################################################
### chunk number 16: 
###################################################
predict(mod1)  


###################################################
### chunk number 17: 
###################################################
resid(mod1)


###################################################
### chunk number 18: 
###################################################
AIC(mod1)


###################################################
### chunk number 19: 
###################################################
mod1.1 <- lm(Response ~ Dose, 
             subset =  Month == 9 & Dose < 40, 
             data = dat, 
             na.action = na.exclude) 


###################################################
### chunk number 20: 
###################################################
predict(mod1.1)

## Note that the predict(mod1.1) is padded with an 
## NA for the first element, because the response was missing 
## for that record and mod1.1 specified na.action = na.exclude. 
## By contrast, predict(mod1) does not pad for the missing 
## observation, because mod1 used the default na.action = na.omit

## The advantage of mod1.1 versus mod1 can be see 
## when we try to merge the predictions with the original data frame: 

sdat <- subset(dat, Month == 9 & Dose < 40)

sdat$Pred <- predict(mod1) ## gives error, because predictions weren't padded
sdat$Pred <- predict(mod1.1) ## this works fine, padding with NA prediction

###################################################
### chunk number 21: 
###################################################

## But what if we want an actual prediction for that first observation?
## We would need to recreate the X values: 

newx <- subset(dat,  
							 Month == 9 & Dose < 40, 
							 select = Dose)

## And then say we want predictions for "new data" with those X values: 
          		 
sdat$Pred2 <- predict(mod1.1, 
                     newdata = newx
                     )

## Note the difference between Pred and Pred2: 

head(sdat)

###################################################
### chunk number 22: 
###################################################

xyplot(Response ~ Dose,
        subset = Month == 9 & Dose < 40, 
        data = dat)

print(
      xyplot(Response ~ factor(Dose),
             subset = Month == 9 & Dose < 40, 
             data = dat)
      )


###################################################
### chunk number 23: 
###################################################
mod2 <- lm(Response ~ factor(Dose),
           subset =  Month == 9 & Dose < 40, 
           data = dat)
summary(mod2)


###################################################
### chunk number 24: 
###################################################
print(
      xyplot(Response ~ Dose, 
             subset =  Month == 9 & Dose < 40, 
             data = dat,
             panel = function(x, y, ...) { 
               panel.xyplot(x, y, ...)
               ux <- sort(unique(x))
               m1pred <- predict(mod1, newdata = data.frame(Dose = ux))
               m2pred <- predict(mod2, newdata = data.frame(Dose = ux))
               panel.xyplot(ux, m1pred, type = 'l', lwd = 2)
               panel.xyplot(ux, m2pred, pch = 19, cex = 1.5)
               }
             )
      )


###################################################
### chunk number 25: 
###################################################

## By default the reference level for the predictor 
## will be its first factor level:

levels(factor(dat$Dose))[1]

## If for some strange reason we wanted to use 10 
## as the reference level, an easy way to do this is: 

dat$Dose2 <- factor(dat$Dose, levels = c("10",  "30",  "100", "0"))
mod2.1 <- lm(Response ~ Dose2,
           subset =  Month == 9 & Dose < 40, 
           data = dat)

###################################################
### chunk number 26: 
###################################################
print(
      xyplot(log(Response) ~ Dose, 
             subset =  Month == 9 & Dose < 40, 
             data = dat
             )
      )


###################################################
### chunk number 27: 
###################################################
library(nlme)
mod3 <- nls(log(Response) ~ alpha + Dose^beta, 
            subset =  Month == 9 & Dose < 40, 
            data = dat, 
            start = list(alpha = log(10), beta = 0.5)
            )


###################################################
### chunk number 28: 
###################################################
summary(mod3)


###################################################
### chunk number 29: 
###################################################
confint(mod3)


###################################################
### chunk number 30: 
###################################################
AIC(mod3)


###################################################
### chunk number 31: 
###################################################
print(
      plot(mod3)
      )


###################################################
### chunk number 32: 
###################################################
print(
      xyplot(log(Response) ~ Dose, 
             subset =  Month == 9 & Dose < 40, 
             data = dat,
             panel = function(x, y, ...) { 
               panel.xyplot(x, y, ...)
               xx <- seq(min(x, na.rm = TRUE), max(x, na.rm = TRUE), length = 100)
               m3pred <- predict(mod3, newdata = data.frame(Dose = xx))
               panel.xyplot(xx, m3pred, type = 'l', lwd = 2)
             }
             )
      )


###################################################
### chunk number 33: 
###################################################
print(
      xyplot(Response ~ Month | Subject, data = dat, 
             subset = Month < 9 & Dose == 30, 
             panel = function(x, y, ...) { 
               panel.xyplot(x, y, ...)
               panel.lmline(x, y, ...)
             }
             )      
      )


###################################################
### chunk number 34: 
###################################################
mod4 <- lme(fixed = Response ~ 1 + Month, 
            data = dat, 
            random = ~ 1 | Subject, 
            subset = Month < 9 & Dose == 30
            )
mod4


###################################################
### chunk number 35: 
###################################################
lme(Response ~ 1 + Month, 
            data = dat, 
            random = list(Subject = pdDiag(~ 1 + Month)), 
            subset = Month < 9 & Dose == 30, 
            na.action = na.exclude
            )


###################################################
### chunk number 36: 
###################################################
mod5 <- lme(Response ~ 1 + Month, 
            data = dat, 
            random = list(Subject = pdDiag(~ -1 + Month)), 
            subset = Dose == 30, 
            na.action = na.exclude
            )
mod5


###################################################
### chunk number 37: 
###################################################
print(
      xyplot(Response ~ Month | Subject, data = dat, 
             subset = Dose == 30 & Month < 9, 
             panel = function(x, y, subscripts, ...) { 
               panel.xyplot(x, y, ...)
               subjectData <- dat[subscripts, ]
               indPred <- predict(mod5, newdata = subjectData)
               popPred <- predict(mod5, newdata = subjectData, level = 0)
               panel.xyplot(subjectData$Month, indPred, type = "l", lty = 2)
               panel.xyplot(subjectData$Month, popPred, type = "l", lty = 1)
             }
             )      
      )


###################################################
### chunk number 38: 
###################################################
print(
      xyplot(resid(mod5) ~ fitted(mod5))
      )


###################################################
### chunk number 39: 
###################################################
print(
      xyplot(resid(mod5, level = 0) ~ fitted(mod5, level = 0))
      )


###################################################
### chunk number 40: 
###################################################
tmp1 <- nls(log(Response) ~ SSasymp(Exposure, Asym, R0, lrc),
            data = dat,
            subset = Month == 9
            )
tmp1


###################################################
### chunk number 41: 
###################################################
mod6 <- nlme(model = log(Response) ~ SSasymp(Exposure, Asym, R0, lrc),
             data = dat, 
             subset = Month %in% c(6, 9), 
             fixed = list(Asym ~ 1, R0 ~ 1, lrc ~ 1), 
             random = list(Asym ~ 1, R0 ~ 1),
             groups = ~ Subject,
             start = coef(tmp1),
             na.action = na.exclude
             )
mod6


###################################################
### chunk number 42: 
###################################################
print(
      xyplot(log(Response) ~ Month | Subject, data = dat,
             subset = Month %in% c(6, 9), 
             panel = function(x, y, subscripts, ...) { 
               panel.xyplot(x, y, ...)
               subjectData <- dat[subscripts, ]
               indPred <- predict(mod6, newdata = subjectData)
               popPred <- predict(mod6, newdata = subjectData, level = 0)
               panel.xyplot(subjectData$Month, indPred, type = "l", lty = 2)
               panel.xyplot(subjectData$Month, popPred, type = "l", lty = 1)
             }
             ) 
      )


###################################################
### chunk number 43: 
###################################################
p <- coef(tmp1)
mod7 <- nlme(model = log(Response) ~ SSasymp(Exposure, Asym, R0, lrc), 
             data = dat, 
             fixed = list(Asym ~ factor(Month), R0 ~ 1, lrc ~ 1), 
             random = list(Asym ~ 1, R0 ~ 1),
             groups = ~ Subject,
             start = c(p["Asym"], 0, 0, 0, p[c("R0", "lrc")]),
             na.action = na.exclude
             )
mod7


###################################################
### chunk number 44: 
###################################################
print(
      xyplot(log(Response) ~ Month | Subject, data = dat,
             panel = function(x, y, subscripts, ...) { 
               panel.xyplot(x, y, ...)
               subjectData <- dat[subscripts, ]
               indPred <- predict(mod7, newdata = subjectData)
               popPred <- predict(mod7, newdata = subjectData, level = 0)
               panel.xyplot(subjectData$Month, indPred, type = "l", lty = 2)
               panel.xyplot(subjectData$Month, popPred, type = "l", lty = 1)
             }
             ) 
      )

## Note na.exclude did not work above. 

datNoMiss <- subset(dat, !is.na(Response))

datNoMiss$Pred <- predict(mod7, newdata = datNoMiss, level = 0)

print(
      xyplot(log(Response) ~ Month | paste(Subject), data = dat,
             
      			 panel = function(x, y, subscripts, ...) { 
               panel.xyplot(x, y, ...)
               subjId <- unique(dat$Subject[subscripts])
               ## grid.text(as.character(subjId))
               popPred <- datNoMiss$Pred[datNoMiss$Subject == subjId]
              panel.xyplot(datNoMiss$Month[datNoMiss$Subject == subjId], popPred, type = "l", lty = 1)
             }
      			 
             ) 
      )



#############################################################################

load('modelinginr/predcheckdata.Rsave')

demo$Type[demo$Type == "ub"] <- 'ub'
demo$Type[demo$Type == "lb"] <- 'lb'
demo$Type[demo$Type == "med"] <- 'est'

mykey1 <- draw.key(list(text = list(c('95th', '50th', '5th')), rectangles = list(col = c('grey', 'palegreen4', 'grey'))))
									 
mykey2 <- draw.key(list(text = list(c('obs', 'pred')), lines = list(lty = 1:2, type = c('b', 'l'), pch = c(19, 0))	))

xyplot(
         
    Response ~ Time | paste("Study", Study), 
    data = demo,
    panel = function(x, y, subscripts, ...) {

      type <- demo$Type[subscripts] 
      set <- demo$PopQuantile[subscripts] 

      q.05.lb <- y[type=='lb' & set=='q.05']
      q.05.med <- y[type=='est' & set=='q.05']
      q.05.ub <- y[type=='ub' & set=='q.05']
      q.05.obs <- y[type=='obs' & set=='q.05']
      q.05.x <- x[type=='obs' & set=='q.05']
      panel.polygon(c(q.05.x, rev(q.05.x)), c(q.05.lb, rev(q.05.ub)), col = 'grey', border = FALSE, alpha=.4)
      panel.xyplot(q.05.x, q.05.med, type = 'l', lty=2, col='black')
      panel.xyplot(q.05.x, q.05.obs, type='b', pch=19, col='black')

      q.95.lb <- y[type=='lb' & set=='q.95']
      q.95.med <- y[type=='est' & set=='q.95']
      q.95.ub <- y[type=='ub' & set=='q.95']
      q.95.obs <- y[type=='obs' & set=='q.95']
      q.95.x <- x[type=='obs' & set=='q.95']
      panel.polygon(c(q.95.x, rev(q.95.x)), c(q.95.lb, rev(q.95.ub)), col = 'grey', border = FALSE, alpha=.4)
      panel.xyplot(q.95.x, q.95.med, type = 'l', lty=2, col='black')
      panel.xyplot(q.95.x, q.95.obs, type='b', pch=19, col='black')

      med.lb <- y[type=='lb' & set=='med']
      med.med <- y[type=='est' & set=='med']
      med.ub <- y[type=='ub' & set=='med']
      med.obs <- y[type=='obs' & set=='med']
      med.x <- x[type=='obs' & set=='med']
      panel.polygon(c(med.x, rev(med.x)), c(med.lb, rev(med.ub)), col = 'palegreen4', border = FALSE, alpha=.4)
      panel.xyplot(med.x, med.med, type = 'l', lty=2, col='black')
      panel.xyplot(med.x, med.obs, type='b', pch=19, col='black')
    },
         scales = list(x = list(relation = 'free')),
         xlab = "Week",
         ylab = "Concentration (ng/mL)", 
    ## key = list(text = list(c('a', 'b')), points = list(pch = 1:2), space = 'top')
    legend = list(right = list(fun=mykey1), top = list(fun = mykey2))
  )

				 
